package com.goldenwater.slaj.ttsa.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertChaTran;

@Mapper
public interface BisTtsaCertChaTranMapper {
    BisTtsaCertChaTran selectBisTtsaCertChaTranByGuid(String guid);
    List<BisTtsaCertChaTran> selectBisTtsaCertChaTranList(BisTtsaCertChaTran bisTtsaCertChaTran);
    int insertBisTtsaCertChaTran(BisTtsaCertChaTran bisTtsaCertChaTran);
    int updateBisTtsaCertChaTran(BisTtsaCertChaTran bisTtsaCertChaTran);
    int deleteBisTtsaCertChaTranByGuid(String guid);
    int deleteBisTtsaCertChaTranByGuids(String[] guids);
}
